@@ -69,7 +69,7 @@ new Vue({
   router,
   template: `
     <div id="app">
-      <h1>Basic</h1>
+      <h1>Lazy Loading</h1>
       <ul>
         <li><router-link to="/">/</router-link></li>
         <li><router-link to="/foo">/foo</router-link></li>
