@@ -1,7 +1,13 @@
+const bsStatus = require('../browserstack-send-status')
+
 module.exports = {
+  ...bsStatus(),
+
+  '@tags': ['history'],
+
   'named routes': function (browser) {
     browser
-    .url('http://localhost:8080/named-routes/')
+      .url('http://localhost:8080/named-routes/')
       .waitForElementVisible('#app', 1000)
       .assert.count('li a', 3)
       // assert correct href with base
@@ -26,8 +32,8 @@ module.exports = {
       .assert.containsText('p', 'Current route name: home')
       .assert.containsText('.view', 'Home')
 
-    // check initial visit
-    .url('http://localhost:8080/named-routes/foo')
+      // check initial visit
+      .url('http://localhost:8080/named-routes/foo')
       .waitForElementVisible('#app', 1000)
       .assert.containsText('p', 'Current route name: foo')
       .assert.containsText('.view', 'Foo')
